==> com_clubmanagement_1.1.zip: admin/views/contacts/tmpl/default.php <==
<?php defined('_JEXEC') or die('Restricted access'); ?>
<?php
JHTML::_('behavior.tooltip');
#print_r($this->contacts);
#echo "<hr/>";
#echo "<pre>";
#print_r($this->contacts);
#echo "</pre>";
#echo "<hr/>";
$contacttypes=$this->contacttypes;
$page = &$this->get('Pagination');
//print_r($page);

#echo JText::_("COM_CLUBMANAGEMENT_ORDERUP");
#echo JText::_("COM_CLUBMANAGEMENT_ORDERDOWN");
?>

<script type="text/javascript">
</script>

<form action="index.php" method="post" name="adminForm">
	<fieldset>
		<legend><?php echo JText::_("COM_CLUBMANAGEMENT_CONTACT_DATA");?></legend>
		<table style="width: 60%;" class="adminlist" id="contactdatatable">
			<thead>
			<tr>
				<th><?php echo JText::_('COM_CLUBMANAGEMENT_CONTACT_TYPE');?></th>
				<th><?php echo JText::_('COM_CLUBMANAGEMENT_CONTACT_DATA');?></th>
				<th><?php echo JText::_('ORDER');?></th>
				<th><?php echo JText::_('DELETE');?></th>
			</tr>
			</thead>
			<tfoot>
			<tr>
				<td style="text-align:left;"><?php echo JHTML::_('select.genericlist',  $contacttypes, "newcontacttype", "", "contacttype_id", "contact", NULL); ?></td>
				<td style="text-align:left;"><input type="text" name="newcontactdata" id="newcontactdata" size="50" /></td>
				<td>
					<div id="newcontactorder">
						<a href="#"><?php echo LegendHelper::renderMultiIcon("reorder", "up"); ?></a>
						<input type="text" disabled="disabled" size="5" class="text_area" style="text-align: center;" />
						<a href="#"><?php echo LegendHelper::renderMultiIcon("reorder", "down"); ?></a>
					</div>
				</td>
				<td><a href="#" onclick="createContactRow('contactdatatable', 'tbody'); return false;" id="newcontactadd"><?php echo LegendHelper::renderMultiIcon("manageitem", "add"); ?></a></td>
			</tr>
			</tfoot>
			<tbody>
<?php
$i=0;

foreach($this->contacts as $item) {
	//	Erledigt fehlerhafte Sortierungen und löscht Lücken
	$item->contactpriority = $i+1;
?>
			<tr class="row<?php echo $i%2;?>">
				<td style="text-align:left;"><?php echo JHTML::_('select.genericlist',  $contacttypes, "contacttype[]", "", "contacttype_id", "contact", $item->contacttype_id, "contacttype_".$i); ?></td>
				<td style="text-align:left;"><input type="hidden" name="contacts_id[]" value="<?php echo $item->contacts_id;?>"/><input type="text" name="contactdata[]" value="<?php echo $item->contactdata;?>" size="50" /></td>
				<td style="text-align:center;">
					<div>
						<a href="#" onclick="reorderUp(this); return false;"><?php echo LegendHelper::renderMultiIcon("reorder", "up"); ?></a>
						<input type="text" name="contactpriority[]" size="5" value="<?php echo $item->contactpriority; ?>" class="text_area" style="text-align: center; " />
						<a href="#" onclick="reorderDown(this); return false;"><?php echo LegendHelper::renderMultiIcon("reorder", "down"); ?></a>
					</div>
				</td>
				<td><a href="#" onclick="deleteTableRow(this); return false;" style="display: block; text-align:center;" ><?php echo LegendHelper::renderMultiIcon("manageitem", "delete"); ?></a></td>
			</tr>
<?php
	$i++;
}
?>
			</tbody>
		</table>
	</fieldset>
<?php
#print_r(get_defined_constants());
?>
<input type="hidden" name="option" value="com_clubmanagement" />
<input type="hidden" name="view" value="contacts" />
<input type="hidden" name="task" value="edit" />
<input type="hidden" name="people_id" value="<?php echo $this->people_id;?>"/>

</form>

==> com_clubmanagement_1.3.zip: admin/views/contacts/tmpl/default.php <==
<?php defined('_JEXEC') or die('Restricted access'); ?>
<?php
JHTML::_('behavior.tooltip');
#print_r($this->contacts);
#echo "<hr/>";
#echo "<pre>";
#print_r($this->contacts);
#echo "</pre>";
#echo "<hr/>";
$contacttypes=$this->contacttypes;
array_unshift($contacttypes, array('id'=>0, 'title'=>JText::_('COM_CLUBMANAGEMENT_PLEASE_CHOSE')));
//print_r($contacttypes);
$page = $this->get('Pagination');
//print_r($page);

#echo JText::_("COM_CLUBMANAGEMENT_ORDERUP");
#echo JText::_("COM_CLUBMANAGEMENT_ORDERDOWN");
?>

<script type="text/javascript">
</script>

<form action="index.php" method="post" name="adminForm">
	<fieldset>
		<legend><?php echo JText::_("COM_CLUBMANAGEMENT_CONTACT_DATA");?></legend>
		<table style="width: 60%;" class="adminlist" id="contactdatatable">
			<thead>
			<tr>
				<th><?php echo JText::_('COM_CLUBMANAGEMENT_CONTACT_TYPE');?></th>
				<th><?php echo JText::_('COM_CLUBMANAGEMENT_CONTACT_DATA');?></th>
				<th><?php echo JText::_('ORDER');?></th>
				<th><?php echo JText::_('DELETE');?></th>
			</tr>
			</thead>
			<tfoot>
			<tr>
				<td style="text-align:left;"><?php echo JHTML::_('select.genericlist',  $contacttypes, "newcontacttype", "", "id", "title", NULL); ?></td>
				<td style="text-align:left;"><input type="text" name="newcontactdata" id="newcontactdata" size="50" /></td>
				<td>
					<div id="newcontactorder">
						<a href="#"><?php echo LegendHelper::renderMultiIcon("reorder", "up"); ?></a>
						<input type="text" disabled="disabled" size="5" class="text_area" style="text-align: center;" />
						<a href="#"><?php echo LegendHelper::renderMultiIcon("reorder", "down"); ?></a>
					</div>
				</td>
				<td><a href="#" onclick="createContactRow('contactdatatable', 'tbody'); return false;" id="newcontactadd"><?php echo LegendHelper::renderMultiIcon("manageitem", "add"); ?></a></td>
			</tr>
			</tfoot>
			<tbody>
<?php
$i=0;

foreach($this->contacts as $item) {
	//	Erledigt fehlerhafte Sortierungen und löscht Lücken
	$item->contactpriority = $i+1;
?>
			<tr class="row<?php echo $i%2;?>">
				<td style="text-align:left;"><?php echo JHTML::_('select.genericlist',  $contacttypes, "contacttype[]", "", "id", "title", $item->contacttype_id, "contacttype_".$i); ?></td>
				<td style="text-align:left;"><input type="hidden" name="contacts_id[]" value="<?php echo $item->contacts_id;?>"/><input type="text" name="contactdata[]" value="<?php echo $item->contactdata;?>" size="50" /></td>
				<td style="text-align:center;">
					<div>
						<a href="#" onclick="reorderUp(this); return false;"><?php echo LegendHelper::renderMultiIcon("reorder", "up"); ?></a>
						<input type="text" name="contactpriority[]" size="5" value="<?php echo $item->contactpriority; ?>" class="text_area" style="text-align: center; " />
						<a href="#" onclick="reorderDown(this); return false;"><?php echo LegendHelper::renderMultiIcon("reorder", "down"); ?></a>
					</div>
				</td>
				<td><a href="#" onclick="deleteTableRow(this); return false;" style="display: block; text-align:center;" ><?php echo LegendHelper::renderMultiIcon("manageitem", "delete"); ?></a></td>
			</tr>
<?php
	$i++;
}
?>
			</tbody>
		</table>
	</fieldset>
<?php
#print_r(get_defined_constants());
?>
<input type="hidden" name="option" value="com_clubmanagement" />
<input type="hidden" name="view" value="contacts" />
<input type="hidden" name="task" value="edit" />
<input type="hidden" name="people_id" value="<?php echo $this->people_id;?>"/>

</form>
